@@ -31,6 +31,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_assistant_reconcile_config.h"
@@ -45,6 +46,7 @@
 #include "utils_dates.h"
 #include "gsb_real.h"
 #include "gsb_reconcile_config.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "utils.h"
 #include "structures.h"
@@ -165,7 +167,7 @@ GtkResponseType gsb_assistant_reconcile_config_run ( void )
 
     if (!transactions_list)
     {
-	dialogue (_("No marked transactions without reconciliation found !"));
+	dialogue (_("No marked transactions without reconciliation found!"));
 	return GTK_RESPONSE_CANCEL;
     }
 
@@ -174,9 +176,9 @@ GtkResponseType gsb_assistant_reconcile_config_run ( void )
 
     /* come here if we have some orphan transactions
      * this can happen by 2 ways :
-     * for old users of grisbi, before i don't remember what version, there were no reconcile number,
+     * for old users of Grisbi, before i don't remember what version, there were no reconcile number,
      * 		the reconciled transactions were juste marked R
-     * before the 0.6.0, ctrl R didn't permit to choose a reconcile
+     * before the 0.6.0, ctrl R didn't permit to choose a reconciliation
      *
      * for the 2nd item, no problem, we show a list of reconciles and the user can choose what reconcile he wants
      * for the first item the problem is there is no reconcile number to go with that transactions...
@@ -190,10 +192,10 @@ GtkResponseType gsb_assistant_reconcile_config_run ( void )
 
     /* first, create the assistant */
     tmpstr = g_strdup_printf (_("Grisbi found %d marked transactions not associated with a reconciliation number, "
-						       "this can happen for old users of grisbi or from a misuse of the Ctrl-R shortcut.\n\n"
+						       "this can happen for old users of Grisbi or from a misuse of the Ctrl-R shortcut.\n\n"
 						       "This assistant will help you make the link between such transactions and a reconciliation.\n\n"
 						       "Before continuing, you should first check if all the dates of the existing reconciliations are good "
-						       "because grisbi will try to guess them not very precisely "
+						       "because Grisbi will try to guess them not very precisely "
 						       "(you will be able to create new reconciliations in the next step). "
 						       "Previous reconciliations will be available too."),
 						       transactions_to_link );
@@ -320,8 +322,9 @@ static GtkWidget *gsb_assistant_reconcile_config_page_menu ( GtkWidget *assistan
 			 button,
 			 FALSE, FALSE, 0 );
 
-    label = gtk_label_new (_("	This will make all the work for you if you create previously all the needed reconciles\n"
-			     "	and adjust the date of the known reconciles."));
+    label = gtk_label_new (_("	This will make all the work for you if you create "
+                        "previously all the needed reconciliations\n"
+                        "	and adjust the date of the known reconciliations."));
     gtk_misc_set_alignment ( GTK_MISC (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (page),
@@ -330,7 +333,8 @@ static GtkWidget *gsb_assistant_reconcile_config_page_menu ( GtkWidget *assistan
 
     /* associate the transactions without reconcile number by hand */
     button = gtk_radio_button_new_with_label ( gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)),
-					       _("Associate by hands the transactions without reconciliation number with the known reconciles"));
+                        _("Associate by hands the transactions without "
+                        "reconciliation number with the known reconciliation"));
     g_object_set_data ( G_OBJECT (button),
 			"next_page", GINT_TO_POINTER (RECONCILE_ASSISTANT_MANUALLY_ASSOCIATE));
     g_signal_connect ( G_OBJECT (button),
@@ -377,7 +381,7 @@ static GtkWidget *gsb_assistant_reconcile_config_page_new_reconcile ( void )
     gtk_container_set_border_width ( GTK_CONTAINER(page), 12 );
 
     paddingbox = new_paddingbox_with_title ( page, FALSE,
-					     _("Fill the fields and click the button \"Create the new reconcile\""));
+					     _("Fill the fields and click the button \"Create the new reconciliation\""));
 
     /* create the table, this is the same as the reconcile config,
      * but here it's to create new ones */
@@ -387,7 +391,7 @@ static GtkWidget *gsb_assistant_reconcile_config_page_new_reconcile ( void )
 	gtk_box_pack_start ( GTK_BOX (paddingbox), table, FALSE, FALSE, 0 );
 
 	/* set the name */
-	label = gtk_label_new ( _("Name: ") );
+	label = gtk_label_new ( _("Reconciliation reference: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
@@ -535,10 +539,10 @@ static GtkWidget *gsb_assistant_reconcile_config_page_automatically_associate (
 			 separator,
 			 FALSE, FALSE, 0 );
 
-    label = gtk_label_new ( _("This assistant try to find a reconciliation to each orphan transaction,\n"
-			     "according to the date of the transaction and the dates of the reconcile.\n"
+    label = gtk_label_new ( _("This assistant try to find a bank reconciliation to each orphan transaction,\n"
+			     "according to the date of the transaction and the dates of the reconciliations.\n"
 			     "If all the orphan transactions cannot be linked here, you should check\n"
-			     "if you did create all the necessary reconciles (first choice in the assistant\n"
+			     "if you did create all the necessary reconciliations (first choice in the assistant\n"
 			     "menu page) or check the transactions themselves."));
     gtk_misc_set_alignment ( GTK_MISC (label),
 			     0, 0.5 );
@@ -677,7 +681,7 @@ static GtkWidget *gsb_assistant_reconcile_config_page_manually_associate ( GtkWi
 			 hbox,
 			 FALSE, FALSE,
 			 10 );
-    button = gtk_button_new_with_label ( _("Link the selection to a reconcile..."));
+    button = gtk_button_new_with_label ( _("Link the selection to a reconciliation..."));
     g_signal_connect ( G_OBJECT (button),
 		       "clicked",
 		       G_CALLBACK (gsb_assistant_reconcile_config_lauch_manu_asso),
@@ -706,8 +710,8 @@ static GtkWidget *gsb_assistant_reconcile_config_page_success ( void )
     page = gtk_vbox_new ( FALSE, 0 );
     gtk_container_set_border_width ( GTK_CONTAINER(page), 12 );
 
-    label = gtk_label_new (_("Congratulation !\n\n"
-			     "You have linked all the transactions without reconcile.\n"
+    label = gtk_label_new (_("Congratulations!\n\n"
+			     "You have linked all the transactions without reconciliation.\n"
 			     "Normally you needn't have to come back to that assistant ; it shouldn't have any way now\n"
 			     "	to have some transactions without reconciliation number."));
     gtk_box_pack_start ( GTK_BOX (page),
@@ -747,11 +751,11 @@ static gboolean gsb_assistant_reconcile_config_page_menu_toggled ( GtkWidget *bu
 
 
 /**
- * called when the user click on the button 'create the new reconcile'
- * check the entries and create the corresponding reconcile
+ * called when the user click on the button 'create the new reconciliation'
+ * check the entries and create the corresponding reconciliation
  *
  * \param button
- * \param label a message label, hidden at the beginning, that will say ok the reconcile is created
+ * \param label a message label, hidden at the beginning, that will say ok the reconciliation is created
  * 		or if there is a problem...
  *
  * \return FALSE
@@ -784,7 +788,7 @@ static gboolean gsb_assistant_reconcile_config_page_add_new_reconcile ( GtkWidge
     /* check there is a name */
     if ( !strlen (gtk_entry_get_text ( GTK_ENTRY ( reconcile_name_entry ) ) ) )
     {
-        string = make_red ( _("Please give a name to the new reconcile.") );
+        string = make_red ( _("Please give a name to the new reconciliation.") );
         gtk_label_set_markup ( GTK_LABEL ( label) , string );
         gtk_widget_grab_focus ( reconcile_name_entry );
         g_free ( string );
@@ -821,10 +825,10 @@ static gboolean gsb_assistant_reconcile_config_page_add_new_reconcile ( GtkWidge
     gsb_data_reconcile_set_final_date ( reconcile_number,
                         gsb_calendar_entry_get_date ( reconcile_final_date_entry ) );
     gsb_data_reconcile_set_init_balance ( reconcile_number,
-                        gsb_real_get_from_string ( gtk_entry_get_text (
+                        utils_real_get_from_string ( gtk_entry_get_text (
                         GTK_ENTRY (reconcile_init_balance_entry ) ) ) );
     gsb_data_reconcile_set_final_balance ( reconcile_number,
-                        gsb_real_get_from_string ( gtk_entry_get_text (
+                        utils_real_get_from_string ( gtk_entry_get_text (
                         GTK_ENTRY ( reconcile_final_balance_entry ) ) ) );
     gsb_data_reconcile_set_account ( reconcile_number,
                         gsb_account_get_combo_account_number ( reconcile_account_button ) );
@@ -836,7 +840,7 @@ static gboolean gsb_assistant_reconcile_config_page_add_new_reconcile ( GtkWidge
     gtk_entry_set_text ( GTK_ENTRY (reconcile_init_balance_entry), "" );
     gtk_entry_set_text ( GTK_ENTRY (reconcile_final_balance_entry), "" );
 
-    string = make_blue ( g_strdup_printf ( _("Reconciliation %s successfully appended !"),
+    string = make_blue ( g_strdup_printf ( _("Reconciliation %s successfully appended!"),
                         gsb_data_reconcile_get_name ( reconcile_number ) ) );
     gtk_label_set_markup ( GTK_LABEL ( label ), string );
     g_free ( string );
@@ -894,7 +898,7 @@ gboolean gsb_assistant_reconcile_config_update_auto_asso ( GtkWidget *assistant,
 
     /* calculate how many transactions can be associated automatically,
      * to avoid to do that 2 times, we set each transactions in a structure with
-     * the associated number of reconcile */
+     * the associated number of bank reconciliation */
     if (list_association)
     {
 	g_slist_free (list_association);
@@ -942,16 +946,16 @@ gboolean gsb_assistant_reconcile_config_update_auto_asso ( GtkWidget *assistant,
 
     if (associate_number)
     {
-	string = g_strdup_printf (_("Grisbi can associate %d transactions to a reconcile.\n"
-				    "Please click on the launch button to create the links"),
-				  associate_number);
+	string = g_strdup_printf (_("Grisbi can associate %d transactions to a reconciliation.\n"
+                        "Please click on the launch button to create the links."),
+                        associate_number);
 	gtk_widget_set_sensitive ( button_run_association,
 				   TRUE );
     }
     else
     {
-	string = my_strdup (_("There is no transaction that grisbi can link.\n"
-			      "Check if you created all the necesssary reconciles."));
+	string = my_strdup (_("There is no transaction that Grisbi can link.\n"
+			      "Check if you created all the necesssary reconciliations."));
 	gtk_widget_set_sensitive ( button_run_association,
 				   FALSE );
     }
@@ -996,7 +1000,7 @@ static gboolean gsb_assistant_reconcile_config_lauch_auto_asso ( GtkWidget *butt
 
     /* now there is 2 way :
      * either transactions_to_link is 0, we go directly to the succes page
-     * either it's not null, and the user should create more reconciles */
+     * either it's not null, and the user should create more reconciliations */
     if (transactions_to_link)
     {
 	gchar *string;
@@ -1011,8 +1015,8 @@ static gboolean gsb_assistant_reconcile_config_lauch_auto_asso ( GtkWidget *butt
 				 0, 0.5 );
 
 	gtk_label_set_text ( GTK_LABEL (label_possible_association),
-			     _("There is no transaction that grisbi can link.\n"
-			       "Check if you created all the necesssary reconciles."));
+			     _("There is no transaction that Grisbi can link.\n"
+			       "Check if you created all the necesssary reconciliations."));
 	gtk_widget_set_sensitive ( button_run_association,
 				   FALSE );
     }
@@ -1071,7 +1075,7 @@ gboolean gsb_assistant_reconcile_config_update_manu_asso ( GtkWidget *assistant,
 	    GtkTreeIter iter;
 
 	    date_str = gsb_format_gdate (gsb_data_transaction_get_date (transaction_number));
-	    amount_str = gsb_real_get_string (gsb_data_transaction_get_amount (transaction_number));
+	    amount_str = utils_real_get_string (gsb_data_transaction_get_amount (transaction_number));
 
 	    gtk_list_store_append ( GTK_LIST_STORE (store),
 				    &iter );
@@ -1226,7 +1230,7 @@ static gboolean gsb_assistant_reconcile_config_lauch_manu_asso ( GtkWidget *butt
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell;
 	gchar *titles[] = {
-	    _("Name"), _("Initial date"), _("Final date")
+	    _("Reconciliation reference"), _("Initial date"), _("Final date")
 	};
 	gfloat alignment[] = {
 	    COLUMN_LEFT, COLUMN_CENTER, COLUMN_CENTER
