@@ -121,8 +121,8 @@ gboolean gsb_scheduler_increase_scheduled ( gint scheduled_number )
 	gsb_main_page_update_finished_scheduled_transactions (scheduled_number);
 
 	/* remove the scheduled transaction */
-	/* !! important to remove first from the list... */
-	gsb_scheduler_list_remove_transaction_from_list ( scheduled_number );
+	/* A ce stade la liste n'est pas initialisée  */
+	//~ gsb_scheduler_list_remove_transaction_from_list ( scheduled_number );
 	gsb_data_scheduled_remove_scheduled (scheduled_number);
 	return FALSE;
     }
@@ -355,6 +355,8 @@ gint gsb_scheduler_create_transaction_from_scheduled_transaction ( gint schedule
 gboolean gsb_scheduler_get_category_for_transaction_from_transaction ( gint transaction_number,
 								       gint scheduled_number )
 {
+	gint contra_account_number;
+
     /* if category is set, it's a normal category */
 
     if ( gsb_data_scheduled_get_category_number (scheduled_number))
@@ -383,8 +385,15 @@ gboolean gsb_scheduler_get_category_for_transaction_from_transaction ( gint tran
 	 * except if the target account is -1 then it's a
 	 * transaction with no category */
 
-	if ( gsb_data_scheduled_get_account_number_transfer (scheduled_number) != -1 )
-	{
+	contra_account_number = gsb_data_scheduled_get_account_number_transfer (scheduled_number);
+    if (contra_account_number == 0)
+    {
+      if (run.account_number_is_0 == FALSE)
+        return FALSE;
+    }
+
+    if (contra_account_number != -1)
+    {
 	    gint contra_transaction_number;
 
 	    contra_transaction_number = gsb_form_transaction_validate_transfer ( transaction_number,
@@ -516,14 +525,14 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
 		 * executed more than one time (the easiest way is to check
 		 * all again, i don't think it will have thousand of scheduled transactions,
 		 * so no much waste of time...) */
+
+		/* On protège tmp_list si gsb_scheduler_increase_scheduled () return FALSE */
+		tmp_list = tmp_list->next;
 		if (gsb_scheduler_increase_scheduled (scheduled_number))
 		{
 		    scheduled_transactions_to_take = NULL;
 		    tmp_list = gsb_data_scheduled_get_scheduled_list ();
 		}
-		else
-		    /* the scheduled is finish, so we needn't to check it again ... */
-		    tmp_list = tmp_list -> next;
 	    }
 	    else
 	    {
