@@ -46,10 +46,11 @@ struct gsb_etat_t
     gint no_devise_totaux_tiers;
 
     /* reconciliation */
-    gint reconcile_end_date;        /* Date initiale + 1 mois par défaut */
-    gboolean reconcile_sort;        /* TRUE = Sort by descending date the reconciliations */
+    gint reconcile_end_date;        	/* Date initiale + 1 mois par défaut */
+    gboolean reconcile_sort;        	/* TRUE = Sort by descending date the reconciliations */
+	gboolean form_date_force_prev_year;	/* FALSE = default année en cours TRUE = forcer l'année précédente pour les dates futures */
 
-    /* formulaire */
+	/* formulaire */
     gint affiche_nb_ecritures_listes;
     gint retient_affichage_par_compte;      /* à 1 si les caractéristiques de l'affichage (R, non R ...) diffèrent par compte */
 
@@ -232,6 +233,7 @@ struct gsb_run_t
 
     /* initialisation variables */
     gboolean new_crypted_file;      /* 0 à l'exécution de init_variables () 1 si new crypted file*/
+	gboolean account_number_is_0;   /* TRUE si an account has 0 for number */
 
     /* file stuff */
     time_t file_modification;
