@@ -38,9 +38,12 @@
 /*START_INCLUDE*/
 #include "utils_dates.h"
 #include "dialog.h"
+#include "fenetre_principale.h"
 #include "gsb_calendar_entry.h"
 #include "gsb_form_widget.h"
 #include "gsb_regex.h"
+#include "navigation.h"
+#include "structures.h"
 #include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -324,6 +327,8 @@ GDate *gsb_parse_date_string ( const gchar *date_string )
     GRegex *date_regex;
     gchar **date_tokens = NULL;
     gchar **tab_date = NULL;
+    gboolean year_auto = etat.form_date_force_prev_year;
+	gint page;
     int num_tokens, num_fields;
     int i, j;
 
@@ -420,6 +425,17 @@ GDate *gsb_parse_date_string ( const gchar *date_string )
     if ( ! g_date_valid ( date ) )
         goto invalid;
 
+	/* if page != GSB_SCHEDULER_PAGE && date > today, then we go back one year before
+     * usefull when entering operations just after the new year */
+	page = gsb_gui_navigation_get_current_page ();
+    if (page != GSB_SCHEDULER_PAGE && year_auto)
+    {
+        GDate *today = gdate_today ( );
+        if ( g_date_compare ( today, date ) < 0 )
+            g_date_set_year ( date, g_date_get_year ( today ) - 1 );
+        g_date_free ( today );
+    }
+
     g_strfreev ( tab_date );
     g_strfreev ( date_tokens );
     return date;
@@ -704,6 +720,7 @@ GDate *gsb_date_get_last_banking_day_of_month ( const GDate *date )
     {
     case G_DATE_SUNDAY :
         g_date_subtract_days ( tmp_date, 2 );
+		break;
     case G_DATE_SATURDAY :
         g_date_subtract_days ( tmp_date, 1 );
         break;
@@ -714,7 +731,30 @@ GDate *gsb_date_get_last_banking_day_of_month ( const GDate *date )
     return tmp_date;
 }
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+GDate *gsb_date_get_first_day_of_current_month (void)
+{
+	GDate *tmp_date;
 
+	tmp_date = gdate_today ();
+	g_date_set_day (tmp_date, 1);
+
+	return tmp_date;
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
